@@ -7,6 +7,7 @@ from tkinter import font
 from tkinter import scrolledtext
 from tkinter import simpledialog
 import os,sys
+import re
 
 # Stupid packaging messes with paths...
 SCRIPT_DIR = os.path.dirname(os.path.abspath(__file__))
@@ -221,7 +222,8 @@ nb=ttk.Notebook(pane)
 pane.add(nb,weight=5)
 mainpack(False)
 
-tw=TerminalWindow(nb,background="black",foreground="white",font=("Courier",fontsize,"bold"),insertbackground="white")
+tw=TerminalWindow(nb,background="black",foreground="white",font=("Courier",fontsize,"bold"),
+                  insertbackground="white",wrap="word")
 
 tw.normalfont=myfont
 tw.setFontSize(fontsize)
