@@ -18,6 +18,7 @@ class CodeText(ScrollText):
     tw=None #Terminal window.
     mode:int=0
     syntax:bool=True
+    syntaxlist=set()
     upload:str=""
     linenos:Label=None
 
@@ -109,7 +110,7 @@ class CodeText(ScrollText):
         p.add_command(label="Redo Last Edit Shift+Ctrl+Z",command=self.redo)
         self.textbox.bind("<Shift-Control-z>",self.redo)
         self.textbox.bind("<Shift-Control-Z>",self.redo)
-        p.add_command(label="Redo Syntax",command=self.highlight,underline=10)
+        p.add_command(label="Redo Syntax",command=lambda: self.highlight(True),underline=10)
         p.add_command(label="Close",command=self.close,underline=0)
         if self.mode==CodeText.MODE_PROPERTY:
             p.add_command(label="Edit as Text",command=self.flattenText,underline=3)
@@ -163,7 +164,7 @@ class CodeText(ScrollText):
         self.textbox.delete("1.0",END)
         self.textbox.insert("1.0",text)
         self.textbox.edit_reset()
-        self.highlight()
+        self.highlight(True)
 
     def doPopup(self,event:Event):
         """Do the actual popup"""
@@ -222,6 +223,7 @@ class CodeText(ScrollText):
         height=int(self.textbox.winfo_height()/self.fontctl.metrics("linespace"))
         offset=1 if self.tabtype==CodeText.MODE_CODE else 0
         self.linenosvar.set("\n".join([str(x+topix-offset) for x in range(height)]))
+        self.highlight()
 
     def bracketMatching(self):
         """Match bracket types"""
@@ -376,13 +378,25 @@ class CodeText(ScrollText):
         for tag in self.COLORLIST:
             self.textbox.tag_remove(tag,str(lno)+".0",str(lno)+".end")
     
-    def highlight(self):
-        """Syntax highlight all lines"""
-        for i in range(1,self.lastLine()+1):
-            self.syntaxHighlight(i)
+    def cleartagRegion(self,startno,endno:int):
+        """Remove tags from multiple lines"""
+        for tag in self.COLORLIST:
+            self.textbox.tag_remove(tag,str(startno)+".0",str(endno)+".end")
+    
+    def highlight(self,clear:bool=False):
+        """Syntax highlight all visible lines"""
+        topline=int(self.textbox.index("@0,0").split(".")[0])
+        bottomline=int(self.textbox.index("@0,%d" % self.textbox.winfo_height()).split(".")[0])
+        if clear:
+            self.cleartagRegion(topline,bottomline)
+            self.syntaxlist.clear()
+        for i in range(topline,bottomline+1):
+            if not(i in self.syntaxlist):
+                self.syntaxHighlight(i,False)
+                self.syntaxlist.add(i)
         self.trackLocation()
 
-    def syntaxHighlight(self, lno:int):
+    def syntaxHighlight(self, lno:int, clearline:bool=True):
         line=""
         x:int=0
         
@@ -402,7 +416,8 @@ class CodeText(ScrollText):
         
         if (lno>=self.lastLine()) or (lno<1):
               return
-        self.cleartags(lno)
+        if clearline:              
+            self.cleartags(lno)
         if not(self.syntax): return
         if lno==0 and self.mode==self.MODE_CODE: return # Leave programming line alone.
         line=self.getLine(lno)
